#[repr(C)]pub(crate) struct HTMLInputElement {Show 16 fields
htmlelement: HTMLElement,
input_type: DomRefCell<InputType>,
is_textual_or_password: Cell<bool>,
checked_changed: Cell<bool>,
placeholder: DomRefCell<DOMString>,
size: Cell<u32>,
maxlength: Cell<i32>,
minlength: Cell<i32>,
textinput: DomRefCell<TextInput<EmbedderClipboardProvider>>,
value_dirty: Cell<bool>,
shared_selection: SharedSelection,
form_owner: MutNullableDom<HTMLFormElement>,
labels_node_list: MutNullableDom<NodeList>,
validity_state: MutNullableDom<ValidityState>,
pending_webdriver_response: RefCell<Option<PendingWebDriverResponse>>,
has_scheduled_selectionchange_event: Cell<bool>,
}Fields
htmlelement: HTMLElementinput_type: DomRefCell<InputType>is_textual_or_password: Cell<bool>Whether or not the InputType for this HTMLInputElement renders as
textual input. This is cached so that it can be read during layout.
checked_changed: Cell<bool>placeholder: DomRefCell<DOMString>size: Cell<u32>maxlength: Cell<i32>minlength: Cell<i32>textinput: DomRefCell<TextInput<EmbedderClipboardProvider>>value_dirty: Cell<bool>A SharedSelection that is shared with layout. This can be updated dyanmnically
and layout should reflect the new value after a display list update.
form_owner: MutNullableDom<HTMLFormElement>labels_node_list: MutNullableDom<NodeList>validity_state: MutNullableDom<ValidityState>pending_webdriver_response: RefCell<Option<PendingWebDriverResponse>>has_scheduled_selectionchange_event: Cell<bool>Implementations
Sourceimpl HTMLInputElement
impl HTMLInputElement
fn __assert_parent_type(&self)
Sourceimpl HTMLInputElement
impl HTMLInputElement
fn new_inherited( local_name: LocalName, prefix: Option<Prefix>, document: &Document, ) -> HTMLInputElement
pub(crate) fn new( cx: &mut JSContext, local_name: LocalName, prefix: Option<Prefix>, document: &Document, proto: Option<HandleObject<'_>>, ) -> DomRoot<HTMLInputElement>
pub(crate) fn auto_directionality(&self) -> Option<String>
pub(crate) fn directionality_from_value(value: &str) -> String
fn is_first_strong_character_rtl(value: &str) -> bool
pub(crate) fn input_type(&self) -> Ref<'_, InputType>
Sourcepub(crate) fn is_nontypeable(&self) -> bool
pub(crate) fn is_nontypeable(&self) -> bool
fn does_minmaxlength_apply(&self) -> bool
fn does_pattern_apply(&self) -> bool
fn does_multiple_apply(&self) -> bool
fn does_value_as_number_apply(&self) -> bool
fn does_value_as_date_apply(&self) -> bool
Sourcefn allowed_value_step(&self) -> Option<f64>
fn allowed_value_step(&self) -> Option<f64>
Sourcefn stepped_minimum(&self) -> Option<f64>
fn stepped_minimum(&self) -> Option<f64>
when allowed_value_step and minimum both exist, this is the smallest value >= minimum that lies on an integer step
Sourcefn stepped_maximum(&self) -> Option<f64>
fn stepped_maximum(&self) -> Option<f64>
when allowed_value_step and maximum both exist, this is the smallest value <= maximum that lies on an integer step
Sourcefn default_minimum(&self) -> Option<f64>
fn default_minimum(&self) -> Option<f64>
Sourcefn default_maximum(&self) -> Option<f64>
fn default_maximum(&self) -> Option<f64>
Sourcefn default_range_value(&self) -> f64
fn default_range_value(&self) -> f64
Sourcefn default_step(&self) -> Option<f64>
fn default_step(&self) -> Option<f64>
Sourcefn step_scale_factor(&self) -> f64
fn step_scale_factor(&self) -> f64
Sourcefn default_step_base(&self) -> Option<f64>
fn default_step_base(&self) -> Option<f64>
Sourcefn step_up_or_down(
&self,
cx: &mut JSContext,
n: i32,
dir: StepDirection,
) -> ErrorResult
fn step_up_or_down( &self, cx: &mut JSContext, n: i32, dir: StepDirection, ) -> ErrorResult
Sourcefn suggestions_source_element(&self) -> Option<DomRoot<HTMLDataListElement>>
fn suggestions_source_element(&self) -> Option<DomRoot<HTMLDataListElement>>
Sourcefn suffers_from_being_missing(&self, value: &DOMString) -> bool
fn suffers_from_being_missing(&self, value: &DOMString) -> bool
Sourcefn suffers_from_type_mismatch(&self, value: &DOMString) -> bool
fn suffers_from_type_mismatch(&self, value: &DOMString) -> bool
Sourcefn suffers_from_pattern_mismatch(
&self,
value: &DOMString,
can_gc: CanGc,
) -> bool
fn suffers_from_pattern_mismatch( &self, value: &DOMString, can_gc: CanGc, ) -> bool
Sourcefn suffers_from_bad_input(&self, value: &DOMString) -> bool
fn suffers_from_bad_input(&self, value: &DOMString) -> bool
Sourcefn suffers_from_length_issues(&self, value: &DOMString) -> ValidationFlags
fn suffers_from_length_issues(&self, value: &DOMString) -> ValidationFlags
Sourcefn suffers_from_range_issues(&self, value: &DOMString) -> ValidationFlags
fn suffers_from_range_issues(&self, value: &DOMString) -> ValidationFlags
Sourcepub(crate) fn is_textual_or_password(&self) -> bool
pub(crate) fn is_textual_or_password(&self) -> bool
Whether this input type renders as a basic text input widget.
fn may_have_embedder_control(&self) -> bool
fn handle_key_reaction( &self, cx: &mut JSContext, action: KeyReaction, event: &Event, )
Sourcefn value_for_shadow_dom(&self) -> DOMString
fn value_for_shadow_dom(&self) -> DOMString
Return a string that represents the contents of the element in its displayed shadow DOM.
fn textinput_mut(&self) -> RefMut<'_, TextInput<EmbedderClipboardProvider>>
Sourceimpl HTMLInputElement
impl HTMLInputElement
Sourcepub(crate) fn form_datums(
&self,
submitter: Option<FormSubmitterElement<'_>>,
encoding: Option<&'static Encoding>,
) -> Vec<FormDatum>
pub(crate) fn form_datums( &self, submitter: Option<FormSubmitterElement<'_>>, encoding: Option<&'static Encoding>, ) -> Vec<FormDatum>
https://html.spec.whatwg.org/multipage/#constructing-the-form-data-set Steps range from 5.1 to 5.10 (specific to HTMLInputElement)
Sourcefn radio_group_name(&self) -> Option<Atom>
fn radio_group_name(&self) -> Option<Atom>
fn update_checked_state(&self, cx: &mut JSContext, checked: bool, dirty: bool)
pub(crate) fn is_mutable(&self) -> bool
Sourcepub(crate) fn reset(&self, cx: &mut JSContext)
pub(crate) fn reset(&self, cx: &mut JSContext)
https://html.spec.whatwg.org/multipage/#the-input-element:concept-form-reset-control:
The reset algorithm for input elements is to set its user validity, dirty value flag, and dirty checkedness flag back to false, set the value of the element to the value of the value content attribute, if there is one, or the empty string otherwise, set the checkedness of the element to true if the element has a checked content attribute and false if it does not, empty the list of selected files, and then invoke the value sanitization algorithm, if the type attribute’s current state defines one.
Sourcepub(crate) fn clear(&self, cx: &mut JSContext)
pub(crate) fn clear(&self, cx: &mut JSContext)
https://w3c.github.io/webdriver/#ref-for-dfn-clear-algorithm-3 Used by WebDriver to clear the input element.
fn update_placeholder_shown_state(&self)
pub(crate) fn select_files_for_webdriver( &self, test_paths: Vec<DOMString>, response_sender: GenericSender<Result<bool, ErrorStatus>>, )
Sourcefn sanitize_value(&self, value: &mut DOMString)
fn sanitize_value(&self, value: &mut DOMString)
fn selection(&self) -> TextControlSelection<'_, Self>
Sourcefn implicit_submission(&self, cx: &mut JSContext)
fn implicit_submission(&self, cx: &mut JSContext)
Sourcefn convert_string_to_number(&self, value: &str) -> Option<f64>
fn convert_string_to_number(&self, value: &str) -> Option<f64>
Sourcefn convert_number_to_string(&self, value: f64) -> Option<DOMString>
fn convert_number_to_string(&self, value: f64) -> Option<DOMString>
fn value_changed(&self, cx: &mut JSContext)
Sourcefn show_the_picker_if_applicable(&self)
fn show_the_picker_if_applicable(&self)
pub(crate) fn handle_color_picker_response( &self, cx: &mut JSContext, response: Option<RgbColor>, )
pub(crate) fn handle_file_picker_response( &self, cx: &mut JSContext, response: Option<Vec<SelectedFile>>, )
fn handle_focus_event(&self, event: &FocusEvent)
fn handle_mouse_event(&self, mouse_event: &MouseEvent)